==> siag_3.0.6.orig.tar.gz: siag-3.0.6/egon/tcli.c <==
/*
   Egon Animator
   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef TCL

/*
 * tcli.c
 */

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <time.h>
#include <signal.h>
#include <sys/wait.h>

#include <X11/Xlib.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/xpm.h>

#include "types.h"

#include "../xcommon/Animator.h"
#include "egon.h"

#include <tcl.h>

static Tcl_Interp *interp = NULL;

static int tcl_interpreter;

static void exec_tcl(char *expr)
{
	if (ok2print)
		hide_cur(w_list);
	Tcl_Eval(interp, expr);
	if (ok2print)
		show_cur(w_list);
}

static void execute_action(Widget w, XEvent *event,
			   String *params, Cardinal *num_params)
{
	char b[256];
	int i;

	strcpy(b, params[0]);
	for (i = 1; i < *num_params; i++) {
		strcat(b, " ");
		strcat(b, params[i]);
	}
	exec_expr(tcl_interpreter, b);
}

static XtActionsRec actions[] = {
	{"tcl", execute_action}
};

static int texec_expr(ClientData clientData, Tcl_Interp *interp,
			int argc, char *argv[])
{
	if (argc < 3) return TCL_ERROR;
	exec_expr(name2interpreter(argv[1]), argv[2]);
	Tcl_SetResult(interp, NULL, TCL_STATIC);
	return TCL_OK;
}

int init_tcl_parser(Tcl_Interp *i)
{
	XtAppContext app_context = XtWidgetToApplicationContext(topLevel);
	interp = i;
	XtAppAddActions(app_context, actions, XtNumber(actions));
	Tcl_CreateCommand(interp, "exec-expr", texec_expr, NULL, NULL);
	return tcl_interpreter = register_interpreter("Tcl",
				NULL, exec_tcl);
}

#else
int tcl_dummy;
#endif	/* TCL */

==> siag_3.1.22.orig.tar.gz: siag-3.1.22/egon/tcli.c <==
/*
   Egon Animator
   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.
 */

#ifdef TCL

/*
 * tcli.c
 */

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <time.h>
#include <signal.h>
#include <sys/wait.h>

#include "types.h"

#include "egon.h"

#include <tcl.h>

static Tcl_Interp *interp = NULL;

static int tcl_interpreter;

static void exec_tcl(char *expr)
{
	if (ok2print)
		hide_cur(w_list);
	Tcl_Eval(interp, expr);
	if (ok2print)
		show_cur(w_list);
}

static int texec_expr(ClientData clientData, Tcl_Interp *interp,
			int argc, char *argv[])
{
	if (argc < 3) return TCL_ERROR;
	exec_expr(name2interpreter(argv[1]), argv[2]);
	Tcl_SetResult(interp, NULL, TCL_STATIC);
	return TCL_OK;
}

/* ---
*/
int init_tcl_parser(Tcl_Interp *i)
{
	interp = i;
	Tcl_CreateCommand(interp, "exec-expr", texec_expr, NULL, NULL);
	return tcl_interpreter = register_interpreter("Tcl",
				NULL, exec_tcl);
}

#else
int tcl_dummy;
#endif	/* TCL */
